"""
=======================
Read Antares HDF5 Files
=======================

Seatray has a builtint HDF5 writer. This is how to read the file.
"""

import pandas as pd

store = pd.HDFStore("example.hd5")

# Do a selection on the dataframe

store.CalibratedPulses[store.CalibratedPulses.Event==2]

#############################################################################
# .. raw:: html
#
#    <div>
#    <table border="1" class="dataframe">
#      <thead>
#        <tr style="text-align: right;">
#          <th></th>
#          <th>Run</th>
#          <th>Event</th>
#          <th>exists</th>
#          <th>TriggerCounter</th>
#          <th>string</th>
#          <th>om</th>
#          <th>vector_index</th>
#          <th>time</th>
#          <th>width</th>
#          <th>charge</th>
#          <th>id</th>
#          <th>isTriggered</th>
#        </tr>
#      </thead>
#      <tbody>
#        <tr>
#          <th>0</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>1</td>
#          <td>2</td>
#          <td>0</td>
#          <td>4092.700717</td>
#          <td>NaN</td>
#          <td>0.819998</td>
#          <td>44</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>1</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>1</td>
#          <td>4</td>
#          <td>0</td>
#          <td>3720.667352</td>
#          <td>NaN</td>
#          <td>0.561300</td>
#          <td>129</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>2</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>1</td>
#          <td>8</td>
#          <td>0</td>
#          <td>6121.324395</td>
#          <td>NaN</td>
#          <td>0.423320</td>
#          <td>137</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>3</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>1</td>
#          <td>12</td>
#          <td>0</td>
#          <td>5362.249247</td>
#          <td>NaN</td>
#          <td>0.862963</td>
#          <td>87</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>4</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>1</td>
#          <td>16</td>
#          <td>0</td>
#          <td>5883.653970</td>
#          <td>NaN</td>
#          <td>1.061923</td>
#          <td>23</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>5</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>1</td>
#          <td>18</td>
#          <td>0</td>
#          <td>6930.661182</td>
#          <td>NaN</td>
#          <td>1.000524</td>
#          <td>32</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>6</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>1</td>
#          <td>22</td>
#          <td>0</td>
#          <td>6350.888814</td>
#          <td>NaN</td>
#          <td>0.563675</td>
#          <td>36</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>7</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>1</td>
#          <td>22</td>
#          <td>1</td>
#          <td>3601.034390</td>
#          <td>NaN</td>
#          <td>1.333916</td>
#          <td>38</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>8</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>1</td>
#          <td>27</td>
#          <td>0</td>
#          <td>4062.590055</td>
#          <td>NaN</td>
#          <td>4.466157</td>
#          <td>18</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>9</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>1</td>
#          <td>27</td>
#          <td>1</td>
#          <td>5888.824709</td>
#          <td>NaN</td>
#          <td>1.138825</td>
#          <td>19</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>10</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>1</td>
#          <td>27</td>
#          <td>2</td>
#          <td>5455.589457</td>
#          <td>NaN</td>
#          <td>1.405773</td>
#          <td>21</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>11</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>1</td>
#          <td>37</td>
#          <td>0</td>
#          <td>6709.808404</td>
#          <td>NaN</td>
#          <td>1.510831</td>
#          <td>99</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>12</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>1</td>
#          <td>38</td>
#          <td>0</td>
#          <td>5364.887937</td>
#          <td>NaN</td>
#          <td>0.719694</td>
#          <td>103</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>13</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>1</td>
#          <td>43</td>
#          <td>0</td>
#          <td>5356.120161</td>
#          <td>NaN</td>
#          <td>0.799824</td>
#          <td>52</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>14</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>1</td>
#          <td>45</td>
#          <td>0</td>
#          <td>6787.553895</td>
#          <td>NaN</td>
#          <td>1.957944</td>
#          <td>57</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>15</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>1</td>
#          <td>49</td>
#          <td>0</td>
#          <td>4017.880130</td>
#          <td>NaN</td>
#          <td>0.216622</td>
#          <td>43</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>16</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>1</td>
#          <td>51</td>
#          <td>0</td>
#          <td>3338.428269</td>
#          <td>NaN</td>
#          <td>1.324314</td>
#          <td>47</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>17</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>1</td>
#          <td>51</td>
#          <td>1</td>
#          <td>3293.485042</td>
#          <td>NaN</td>
#          <td>0.491035</td>
#          <td>49</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>18</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>1</td>
#          <td>56</td>
#          <td>0</td>
#          <td>5427.342486</td>
#          <td>NaN</td>
#          <td>0.704921</td>
#          <td>92</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>19</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>1</td>
#          <td>56</td>
#          <td>1</td>
#          <td>4687.966654</td>
#          <td>NaN</td>
#          <td>0.431727</td>
#          <td>93</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>20</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>1</td>
#          <td>72</td>
#          <td>0</td>
#          <td>4506.100426</td>
#          <td>NaN</td>
#          <td>1.465480</td>
#          <td>95</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>21</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>1</td>
#          <td>72</td>
#          <td>1</td>
#          <td>5471.645232</td>
#          <td>NaN</td>
#          <td>0.808342</td>
#          <td>96</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>22</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>2</td>
#          <td>5</td>
#          <td>0</td>
#          <td>4746.251954</td>
#          <td>NaN</td>
#          <td>0.908766</td>
#          <td>26</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>23</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>2</td>
#          <td>12</td>
#          <td>0</td>
#          <td>5435.916521</td>
#          <td>NaN</td>
#          <td>0.522364</td>
#          <td>11</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>24</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>2</td>
#          <td>23</td>
#          <td>0</td>
#          <td>7088.790150</td>
#          <td>NaN</td>
#          <td>0.995929</td>
#          <td>111</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>25</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>2</td>
#          <td>29</td>
#          <td>0</td>
#          <td>4349.021338</td>
#          <td>NaN</td>
#          <td>1.286056</td>
#          <td>24</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>26</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>2</td>
#          <td>31</td>
#          <td>0</td>
#          <td>3719.951229</td>
#          <td>NaN</td>
#          <td>1.333059</td>
#          <td>109</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>27</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>2</td>
#          <td>32</td>
#          <td>0</td>
#          <td>6596.952465</td>
#          <td>NaN</td>
#          <td>1.716753</td>
#          <td>116</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>28</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>2</td>
#          <td>48</td>
#          <td>0</td>
#          <td>6418.124205</td>
#          <td>NaN</td>
#          <td>1.172891</td>
#          <td>124</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>29</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57188</td>
#          <td>2</td>
#          <td>49</td>
#          <td>0</td>
#          <td>4881.411920</td>
#          <td>NaN</td>
#          <td>1.399015</td>
#          <td>90</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>...</th>
#          <td>...</td>
#          <td>...</td>
#          <td>...</td>
#          <td>...</td>
#          <td>...</td>
#          <td>...</td>
#          <td>...</td>
#          <td>...</td>
#          <td>...</td>
#          <td>...</td>
#          <td>...</td>
#          <td>...</td>
#        </tr>
#        <tr>
#          <th>556</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>10</td>
#          <td>72</td>
#          <td>0</td>
#          <td>3724.712423</td>
#          <td>NaN</td>
#          <td>1.364341</td>
#          <td>95</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>557</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>10</td>
#          <td>75</td>
#          <td>0</td>
#          <td>6019.573451</td>
#          <td>NaN</td>
#          <td>1.140176</td>
#          <td>10</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>558</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>11</td>
#          <td>19</td>
#          <td>0</td>
#          <td>4295.049574</td>
#          <td>NaN</td>
#          <td>0.466871</td>
#          <td>142</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>559</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>11</td>
#          <td>29</td>
#          <td>0</td>
#          <td>5377.279026</td>
#          <td>NaN</td>
#          <td>1.135662</td>
#          <td>6</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>560</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>11</td>
#          <td>37</td>
#          <td>0</td>
#          <td>6558.308526</td>
#          <td>NaN</td>
#          <td>1.525232</td>
#          <td>66</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>561</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>11</td>
#          <td>40</td>
#          <td>0</td>
#          <td>6008.048736</td>
#          <td>NaN</td>
#          <td>0.331947</td>
#          <td>46</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>562</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>11</td>
#          <td>40</td>
#          <td>1</td>
#          <td>4770.080887</td>
#          <td>NaN</td>
#          <td>1.614006</td>
#          <td>48</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>563</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>11</td>
#          <td>41</td>
#          <td>0</td>
#          <td>5299.254523</td>
#          <td>NaN</td>
#          <td>0.979528</td>
#          <td>50</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>564</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>11</td>
#          <td>50</td>
#          <td>0</td>
#          <td>6636.216506</td>
#          <td>NaN</td>
#          <td>1.018077</td>
#          <td>87</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>565</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>11</td>
#          <td>51</td>
#          <td>0</td>
#          <td>4696.929434</td>
#          <td>NaN</td>
#          <td>1.592751</td>
#          <td>88</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>566</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>11</td>
#          <td>52</td>
#          <td>0</td>
#          <td>3494.630965</td>
#          <td>NaN</td>
#          <td>1.420392</td>
#          <td>97</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>567</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>11</td>
#          <td>53</td>
#          <td>0</td>
#          <td>4022.118130</td>
#          <td>NaN</td>
#          <td>3.503563</td>
#          <td>99</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>568</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>11</td>
#          <td>53</td>
#          <td>1</td>
#          <td>5980.967789</td>
#          <td>NaN</td>
#          <td>0.861323</td>
#          <td>100</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>569</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>11</td>
#          <td>54</td>
#          <td>0</td>
#          <td>5067.833105</td>
#          <td>NaN</td>
#          <td>1.114462</td>
#          <td>103</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>570</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>11</td>
#          <td>65</td>
#          <td>0</td>
#          <td>3524.701758</td>
#          <td>NaN</td>
#          <td>0.761944</td>
#          <td>157</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>571</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>11</td>
#          <td>73</td>
#          <td>0</td>
#          <td>5538.403486</td>
#          <td>NaN</td>
#          <td>1.011277</td>
#          <td>146</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>572</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>11</td>
#          <td>74</td>
#          <td>0</td>
#          <td>5974.464025</td>
#          <td>NaN</td>
#          <td>1.033400</td>
#          <td>147</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>573</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>12</td>
#          <td>1</td>
#          <td>0</td>
#          <td>6861.397647</td>
#          <td>NaN</td>
#          <td>0.750251</td>
#          <td>137</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>574</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>12</td>
#          <td>4</td>
#          <td>0</td>
#          <td>5113.981138</td>
#          <td>NaN</td>
#          <td>2.185622</td>
#          <td>13</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>575</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>12</td>
#          <td>4</td>
#          <td>1</td>
#          <td>7177.729417</td>
#          <td>NaN</td>
#          <td>2.901098</td>
#          <td>14</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>576</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>12</td>
#          <td>4</td>
#          <td>2</td>
#          <td>5487.483446</td>
#          <td>NaN</td>
#          <td>0.928578</td>
#          <td>17</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>577</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>12</td>
#          <td>5</td>
#          <td>0</td>
#          <td>3905.953008</td>
#          <td>NaN</td>
#          <td>1.253825</td>
#          <td>18</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>578</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>12</td>
#          <td>20</td>
#          <td>0</td>
#          <td>4165.451891</td>
#          <td>NaN</td>
#          <td>0.717164</td>
#          <td>98</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>579</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>12</td>
#          <td>22</td>
#          <td>0</td>
#          <td>4162.596810</td>
#          <td>NaN</td>
#          <td>0.657860</td>
#          <td>153</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>580</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>12</td>
#          <td>23</td>
#          <td>0</td>
#          <td>6405.585797</td>
#          <td>NaN</td>
#          <td>0.857765</td>
#          <td>155</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>581</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>12</td>
#          <td>34</td>
#          <td>0</td>
#          <td>4735.479278</td>
#          <td>NaN</td>
#          <td>1.317987</td>
#          <td>134</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>582</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>12</td>
#          <td>44</td>
#          <td>0</td>
#          <td>4895.268656</td>
#          <td>NaN</td>
#          <td>1.159165</td>
#          <td>154</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>583</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>12</td>
#          <td>46</td>
#          <td>0</td>
#          <td>4078.763691</td>
#          <td>NaN</td>
#          <td>1.371296</td>
#          <td>135</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>584</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>12</td>
#          <td>49</td>
#          <td>0</td>
#          <td>6438.230340</td>
#          <td>NaN</td>
#          <td>1.352533</td>
#          <td>67</td>
#          <td>0</td>
#        </tr>
#        <tr>
#          <th>585</th>
#          <td>45978</td>
#          <td>2</td>
#          <td>1</td>
#          <td>57192</td>
#          <td>12</td>
#          <td>50</td>
#          <td>0</td>
#          <td>3207.006567</td>
#          <td>NaN</td>
#          <td>1.600555</td>
#          <td>69</td>
#          <td>0</td>
#        </tr>
#      </tbody>
#    </table>
#    <p>586 rows × 12 columns</p>
#    </div>
